@@ -71,6 +71,14 @@ def gather_regexes(courts):
     for court in courts:
         for reg_str in court["regex"]:
             regex = re.compile(reg_str, (re.I | re.U))
-            regexes.append((regex, court["id"], court["name"], court["type"]))
+            regexes.append(
+                (
+                    regex,
+                    court["id"],
+                    court["name"],
+                    court["type"],
+                    court.get("location"),
+                )
+            )
 
     return regexes
